@@ -16,7 +16,7 @@ if on_rtd:
     os.environ['HOME'] = '/home/docs/'
     os.environ['LANG'] = 'C'
     os.environ['LC_ALL'] = 'C'
-    os.environ['HIDE_PARFIVE_PROGESS'] = 'True'
+    os.environ['PARFIVE_HIDE_PROGRESS'] = 'True'
 
 # -- Check for dependencies ----------------------------------------------------
 from sunpy.util import missing_dependencies_by_extra  # NOQA
@@ -114,6 +114,7 @@ extensions = [
     'sunpy.util.sphinx.generate',
     "sphinxext.opengraph",
     'sphinx_design',
+    'sphinx_copybutton',
 ]
 
 # Set automodapi to generate files inside the generated directory
@@ -292,6 +293,10 @@ rst_epilog = f"""
 .. _cv2_filter2D: {filter2D_full}
 """
 
+# -- Options for sphinx-copybutton ---------------------------------------------
+# Python Repl + continuation, Bash, ipython and qtconsole + continuation, jupyter-console + continuation
+copybutton_prompt_text = r">>> |\.\.\. |\$ |In \[\d*\]: | {2,5}\.\.\.: | {5,8}: "
+copybutton_prompt_is_regexp = True
 
 # -- Stability Page ------------------------------------------------------------
 with open('./code_ref/sunpy_stability.yaml', 'r') as estability:
