@@ -50,8 +50,9 @@ def test_read_file_fits_multple_hdu():
 
 def test_read_file_fits_gzip():
     # Test read gzipped fits file
-    for fits_extension in [".fts", ".fit", ".fits"]:
-        pair = sunpy.io.read_file(get_test_filepath(f"gzip_test{fits_extension}.gz"))
+    gzip_fits_files = ["gzip_test.fts.gz", "gzip_test.fits.gz", "gzip_test.fit.gz", "gzip_fits_test.file"]
+    for filename in gzip_fits_files:
+        pair = sunpy.io.read_file(get_test_filepath(filename))
         assert isinstance(pair, list)
         assert len(pair) == 1
         assert len(pair[0]) == 2
