@@ -101,7 +101,7 @@ class MapSequence:
             warn_user(f"Rendering the summary for a MapSequence of {nmaps} Maps "
                       "may take a while.")
 
-        # Assemble the individual HTML repr from each Map, all hidden initally
+        # Assemble the individual HTML repr from each Map, all hidden initially
         repr_list = [f"<div style='display: none' index={i}>{m._repr_html_()}</div>"
                      for i, m in enumerate(self.maps)]
 
@@ -350,9 +350,9 @@ class MapSequence:
                 removes.pop(0).remove()
 
             im.set_array(ani_data[i].data)
-            im.set_cmap(ani_data[i].plot_settings['cmap'])
+            im.set_cmap(kwargs.get('cmap', ani_data[i].plot_settings['cmap']))
 
-            norm = deepcopy(ani_data[i].plot_settings['norm'])
+            norm = deepcopy(kwargs.get('norm', ani_data[i].plot_settings['norm']))
             # The following explicit call is for bugged versions of Astropy's
             # ImageNormalize
             norm.autoscale_None(ani_data[i].data)
