@@ -1,12 +1,11 @@
 """
-This module provies GOES XRS `~sunpy.timeseries.TimeSeries` source.
+This module provides GOES XRS `~sunpy.timeseries.TimeSeries` source.
 """
 from pathlib import Path
 from collections import OrderedDict
 
 import h5netcdf
 import matplotlib.dates as mdates
-import matplotlib.ticker as mticker
 import numpy as np
 import packaging.version
 from matplotlib import pyplot as plt
@@ -101,14 +100,11 @@ class XRSTimeSeries(GenericTimeSeries):
         formatter = mdates.ConciseDateFormatter(locator)
         axes.xaxis.set_major_locator(locator)
         axes.xaxis.set_major_formatter(formatter)
-        ax2 = axes.twinx()
-        ax2.set_yscale("log")
-        ax2.set_ylim(1e-9, 1e-2)
         labels = ["A", "B", "C", "M", "X"]
         centers = np.logspace(-7.5, -3.5, len(labels))
-        ax2.yaxis.set_minor_locator(mticker.FixedLocator(centers))
-        ax2.set_yticklabels(labels, minor=True)
-        ax2.set_yticklabels([])
+        for value, label in zip(centers, labels):
+            axes.text(1.02, value, label, transform=axes.get_yaxis_transform(), horizontalalignment='center')
+
         axes.yaxis.grid(True, "major")
         axes.xaxis.grid(False, "major")
         axes.legend()
@@ -127,7 +123,7 @@ class XRSTimeSeries(GenericTimeSeries):
         pattern_1m = ("sci_xrsf-l2-avg1m_g{SatelliteNumber:02d}_d{year:4d}{month:2d}{day:2d}_{}.nc")
         pattern_telescop = ("GOES {SatelliteNumber:02d}")
         # The ordering of where we get the metadata from is important.
-        # We alway want to check ID first as that will most likely have the correct information.
+        # We always want to check ID first as that will most likely have the correct information.
         # The other fields are fallback and sometimes have data in them that is "useless".
         id = (
             self.meta.metas[0].get("id", "").strip()
