@@ -1,5 +1,5 @@
 """
-This module provies NOAA Solar Cycle `~sunpy.timeseries.TimeSeries` source.
+This module provides NOAA Solar Cycle `~sunpy.timeseries.TimeSeries` source.
 """
 from pathlib import Path
 from collections import OrderedDict
@@ -101,8 +101,6 @@ class NOAAIndicesTimeSeries(GenericTimeSeries):
         to_plot = self.to_dataframe()[to_plot]
         to_plot.plot(ax=axes, **kwargs)
 
-        axes.set_xlim(min(to_plot.dropna(how='all').index),
-                      max(to_plot.dropna(how='all').index))
         axes.set_ylim(0)
         axes.set_ylabel(ylabel)
         axes.yaxis.grid(True, 'major')
