@@ -1,5 +1,5 @@
 """
-This module provies the `~sunpy.timeseries.TimeSeriesFactory` class.
+This module provides the `~sunpy.timeseries.TimeSeriesFactory` class.
 """
 import os
 import copy
@@ -17,8 +17,8 @@ from astropy.table import Table
 from astropy.time import Time
 
 import sunpy
+from sunpy.io._fits import HDPair
 from sunpy.io.file_tools import UnrecognizedFileTypeError, detect_filetype, read_file
-from sunpy.io.fits import HDPair
 from sunpy.io.header import FileHeader
 from sunpy.timeseries.timeseriesbase import GenericTimeSeries
 from sunpy.util import expand_list
@@ -439,10 +439,6 @@ class TimeSeriesFactory(BasicRegistrationFactory):
 
             new_timeseries = [full_timeseries]
 
-        # Sanitize any units OrderedDict details
-        for timeseries in new_timeseries:
-            timeseries._sanitize_units()
-
         # Only return single time series, not in a list if we only have one.
         if len(new_timeseries) == 1:
             return new_timeseries[0]
